==> rca-precursor-0.1.20.tgz: package/src/middleware/universal/universal.js <==
//  @flow
import 'require-ensure';
import React from 'react';
import { StaticRouter } from 'react-router';
import { renderToString } from 'react-dom/server';

import type { $Request, $Response } from 'express';
import type { IConfig } from '../../../flow/IConfig';
import type { IApp } from '../../../flow/IApp';

import {
  matchRoute,
  fetchInitialProps,
  getParamsFromUrl,
  getRootString,
  getMetaData,
  getRouteComponent,
} from './../../utils';

export default (app: IApp, config: IConfig) => async (
  req: $Request,
  res: $Response,
  next: Function,
) => {
  const _app = app;
  const {
    root: Root,
    routes,
  } = config;

  const serverProps = {};
  let tmpl = app.locals.html;

  const contextRoute = matchRoute(routes, req.url);
  const component = getRouteComponent(config, contextRoute);
  const { path } = contextRoute;

  //  TODO handle 404's and broken promises
  if (!path) {
    res.status(404);
  }

  //  Fetch any initialProps to populate route data
  const urlParams = getParamsFromUrl(path, req.url);
  serverProps[req.url] = await fetchInitialProps(component.getInitialProps, urlParams);

  //  Get the contextRoute meta data and
  //  populate the html server-side
  const metaData = getMetaData(contextRoute, urlParams);
  Object.keys(metaData).forEach((key) => {
    tmpl = tmpl.replace(`{meta.${key}}`, metaData[key]);
  });

  //  Render the root component in the template
  //  along with the contextRoute
  const rootString = renderToString(
    <StaticRouter location={req.url} context={{}}>
      <Root {...serverProps} />
    </StaticRouter>,
  );

  const reactRoot = getRootString(rootString, serverProps);
  _app.locals.output = tmpl.replace('{react-root}', `<div id="root">${reactRoot}</div>`);

  next();
};

==> rca-precursor-0.1.22.tgz: package/src/middleware/universal/universal.js <==
//  @flow
import 'require-ensure';
import React from 'react';
import { StaticRouter } from 'react-router';
import { renderToString } from 'react-dom/server';

import type { $Request, $Response } from 'express';
import type { IConfig } from '../../../flow/IConfig';
import type { IApp } from '../../../flow/IApp';

import {
  matchRoute,
  fetchInitialProps,
  getParamsFromUrl,
  getRootString,
  getMetaData,
  // getRouteComponent,
} from './../../utils';

export default (app: IApp, config: IConfig) => async (
  req: $Request,
  res: $Response,
  next: Function,
) => {
  const _app = app;
  const {
    root: Root,
    routes,
  } = config;

  const serverProps = {};
  let tmpl = app.locals.html;

  const contextRoute = matchRoute(routes, req.url);
  // const component = contextRoute.bundle
  //   ? getRouteComponent(config, contextRoute)
  //   : contextRoute.component;
  const { path, component } = contextRoute;

  //  TODO handle 404's and broken promises
  if (!path) {
    res.status(404);
  }

  //  Fetch any initialProps to populate route data
  const urlParams = getParamsFromUrl(path, req.url);
  serverProps[req.url] = await fetchInitialProps(component.getInitialProps, urlParams);

  //  Get the contextRoute meta data and
  //  populate the html server-side
  const metaData = getMetaData(contextRoute, urlParams);
  Object.keys(metaData).forEach((key) => {
    tmpl = tmpl.replace(`{meta.${key}}`, metaData[key]);
  });

  //  Render the root component in the template
  //  along with the contextRoute
  const rootString = renderToString(
    <StaticRouter location={req.url} context={{}}>
      <Root {...serverProps} />
    </StaticRouter>,
  );

  const reactRoot = getRootString(rootString, serverProps);
  _app.locals.output = tmpl.replace('{react-root}', `<div id="root">${reactRoot}</div>`);

  next();
};
